Index: testing/android/native_test/java/src/org/chromium/native_test/NativeTestInstrumentationTestRunner.java |
diff --git a/testing/android/native_test/java/src/org/chromium/native_test/NativeTestInstrumentationTestRunner.java b/testing/android/native_test/java/src/org/chromium/native_test/NativeTestInstrumentationTestRunner.java |
index f834d334e636a29c754b5b66619bf59c78b82772..80c76806c2f8551801d23c9e021e26b5269739a6 100644 |
--- a/testing/android/native_test/java/src/org/chromium/native_test/NativeTestInstrumentationTestRunner.java |
+++ b/testing/android/native_test/java/src/org/chromium/native_test/NativeTestInstrumentationTestRunner.java |
@@ -39,7 +39,7 @@ import java.util.regex.Matcher; |
import java.util.regex.Pattern; |
/** |
* An Instrumentation that runs tests based on NativeTestActivity. |
*/ |
public class NativeTestInstrumentationTestRunner extends Instrumentation { |
@@ -232,7 +232,7 @@ public class NativeTestInstrumentationTestRunner extends Instrumentation { |
return false; |
} |
/** Starts the NativeTestActivty. |
*/ |
private class ShardStarter implements Runnable { |
@Override |
@@ -243,9 +243,9 @@ public class NativeTestInstrumentationTestRunner extends Instrumentation { |
i.putExtras(mTransparentArguments); |
if (mShards != null && !mShards.isEmpty()) { |
ArrayList<String> shard = mShards.remove(); |
- i.putStringArrayListExtra(NativeTestActivity.EXTRA_SHARD, shard); |
+ i.putStringArrayListExtra(NativeTest.EXTRA_SHARD, shard); |
} |
- i.putExtra(NativeTestActivity.EXTRA_STDOUT_FILE, mStdoutFile.getAbsolutePath()); |
+ i.putExtra(NativeTest.EXTRA_STDOUT_FILE, mStdoutFile.getAbsolutePath()); |
getContext().startActivity(i); |
} |
} |
@@ -39,7 +39,7 @@ import java.util.regex.Matcher; |
import java.util.regex.Pattern; |
/** |
- * An Instrumentation that runs tests based on NativeTestActivity. |
+ * An Instrumentation that runs tests based on NativeTest. |
*/ |
public class NativeTestInstrumentationTestRunner extends Instrumentation { |
@@ -232,7 +232,7 @@ public class NativeTestInstrumentationTestRunner extends Instrumentation { |
return false; |
} |
- /** Starts the NativeTestActivty. |
+ /** Starts the NativeTest Activity. |
*/ |
private class ShardStarter implements Runnable { |